package compute

import (
	"context"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// SnapshotDeleteRequest struct to delete snapshot
type SnapshotDeleteRequest struct {
	// ID of the compute instance
	// Required: true
	ComputeID uint64 `url:"computeId" json:"computeId" validate:"required"`

	// Text label of snapshot to delete
	// Required: true
	Label string `url:"label" json:"label" validate:"required"`
}

type wrapperSnapshotDeleteRequest struct {
	SnapshotDeleteRequest

	AsyncMode bool `url:"asyncMode"`
}

// SnapshotDelete deletes specified compute snapshot
func (c Compute) SnapshotDelete(ctx context.Context, req SnapshotDeleteRequest) (string, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return "", validators.ValidationErrors(validators.GetErrors(err))
	}

	reqWrapped := wrapperSnapshotDeleteRequest{
		SnapshotDeleteRequest: req,
		AsyncMode:             false,
	}

	url := "/cloudbroker/compute/snapshotDelete"

	res, err := c.client.DecortApiCall(ctx, http.MethodPost, url, reqWrapped)
	if err != nil {
		return "", err
	}

	return string(res), nil
}

// SnapshotDeleteAsync deletes specified compute snapshot with AsyncMode
func (c Compute) SnapshotDeleteAsync(ctx context.Context, req SnapshotDeleteRequest) (string, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return "", validators.ValidationErrors(validators.GetErrors(err))
	}

	reqWrapped := wrapperSnapshotDeleteRequest{
		SnapshotDeleteRequest: req,
		AsyncMode:             true,
	}

	url := "/cloudbroker/compute/snapshotDelete"

	res, err := c.client.DecortApiCall(ctx, http.MethodPost, url, reqWrapped)
	if err != nil {
		return "", err
	}

	return string(res), nil
}
