package disks

import (
	"context"
	"net/http"
	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
	"strconv"
)

// PresentRequest struct to present disk to node
type PresentRequest struct {
	// ID of the disk to present
	// Required: true
	DiskID uint64 `url:"diskId" json:"diskId" validate:"required"`

	// ID of the node to present disk to
	// Required: true
	NodeID uint64 `url:"nodeId" json:"nodeId" validate:"required"`
}

// Present presents disk to node
func (d Disks) Present(ctx context.Context, req PresentRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/disks/present"

	res, err := d.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
